@@ -8,14 +8,13 @@ use LWP::UserAgent;
 use HTTP::Request;
 use HTTP::Headers;
 use XML::Simple;
-use Data::Dumper;
 use Data::UUID;
 use DateTime;
 use Encode;
 
 =head1 NAME 
 
-eBay 
+WebService::eBay 
 
 =head1 SYNOPSIS
 
@@ -25,7 +24,7 @@ The "hello world" equivalent in the eBay API world is to send a call asking for
 
  use WebService::eBay;
  
- my $response = eBay::APICall("GeteBayOfficialTime");
+ my $response = WebService::eBay::APICall("GeteBayOfficialTime");
  print "$response->{Timestamp}\n";
 
 But this isn't a great example for this module because the GeteBayOfficialTime call doesn't take any parameters.  A simple one that does though is the EndItem call.  Here's how you would do that in this module:
@@ -34,7 +33,7 @@ But this isn't a great example for this module because the GeteBayOfficialTime c
  my $callDetails   = "<ItemID>$listingNumber</ItemID>
  <EndingReason>OtherListingError</EndingReason>";
  
- if ( eBay::APICall( "EndItem", $callDetails ) ) {
+ if ( WebService::eBay::APICall( "EndItem", $callDetails ) ) {
  	print "\nDeleted $listingNumber from eBay\n";
  } else {
  	print("\nUnable to end listing $listingNumber\n");
@@ -42,24 +41,24 @@ But this isn't a great example for this module because the GeteBayOfficialTime c
 
 =head1 DESCRIPTION
  
-To use the eBay Trading API you need application keys and an authorization tokens.  You can obtain these through your eBay developer account.  You should create a file called "tokens" in the directory containing the program using this module.  That file should look like this for the API sandbox and testing:
+To use the eBay Trading API you need application keys and an authorization token.  You can obtain these through your eBay developer account.  You should create a file called "tokens" in the directory containing the program using this module.  That file should look like this for the API sandbox and testing:
 
- APIURL=https://api.sandbox.ebay.com/ws/api.dll
- SiteID=0
- DevName=<Your Dev Name>
- AppName=<Your App Name>
- CertName=<Your Cert Name>
- AuthToken=<Your Auth Token>
- Log=true
+ APIURL https://api.sandbox.ebay.com/ws/api.dll
+ SiteID 0
+ DevName <Your Dev Name>
+ AppName <Your App Name>
+ CertName <Your Cert Name>
+ AuthToken <Your Auth Token>
+ Log true
 
 and this for the Production keys.  
 
- APIURL=https://api.ebay.com/ws/api.dll
- SiteID=100
- DevName=<Your Dev Name>
- AppName=<Your App Name>
- CertName=<Your Cert Name>
- AuthToken=<Your Auth Token>
+ APIURL https://api.ebay.com/ws/api.dll
+ SiteID 100
+ DevName <Your Dev Name>
+ AppName <Your App Name>
+ CertName <Your Cert Name>
+ AuthToken <Your Auth Token>
  
 The last option "Log" is intended for testing and sandbox use as it logs all communication sent and received from the API, which includes your secret keys.  To not use this option, leave the "Log" line out of the tokens file or set it to something other than 'true'.
 
@@ -73,7 +72,7 @@ my $value;
 open( $tokens, './tokens' ) or die "Unable to find tokens file $!";
 while (<$tokens>) {
 	chomp;
-	( $name, $value ) = split /=/;
+	( $name, $value ) = split / /;
 	$config{$name} = $value;
 }
 close($tokens);
@@ -104,7 +103,9 @@ The name of the API Call that you wish to make.  For a list of API calls and the
 
 =head4 RequestDetails
 
-The details of the call.  You do not need to provide the RequesterCredentials or the WarningLevel, but you do have to provide the rest of the call.  This is where that goes.  The RequesterCredentials are always the same and the WarningLevel doesn't usually need to be changed.  For information on what details your call needs, visit https://developer.ebay.com/devzone/xml/docs/reference/ebay/index.html  Some calls have no details.
+The details of the call, in XML.  You do not need to provide the RequesterCredentials or the WarningLevel, but you do have to provide the rest of the call.  This is where that goes.  The RequesterCredentials are always the same and the WarningLevel doesn't usually need to be changed.  For information on what details your call needs, visit https://developer.ebay.com/devzone/xml/docs/reference/ebay/index.html  
+
+Some calls have no details, such as GeteBayOfficialTime.
  
 =head4 Xml
 
