@@ -12,7 +12,7 @@ my $listingNumber = '142306955';
 my $callDetails   = "<ItemID>$listingNumber</ItemID>
 <EndingReason>OtherListingError</EndingReason>";
 
-if ( eBay::APICall( "EndItem", $callDetails ) ) {
+if ( WebService::eBay::APICall( "EndItem", $callDetails ) ) {
 	print "\nDeleted $listingNumber from eBay\n";
 } else {
 	print("\nUnable to end listing $listingNumber\n");
